import { ref, computed } from 'vue';

const theme = ref('');
const supportedThemes = ['light', 'dark'];
const uikitThemeClass = computed(() => `tui-theme-${theme.value}`);

export function useTheme() {
  function setTheme(newTheme: string): void {
    if (supportedThemes.includes(newTheme)) {
      theme.value = newTheme;
    } else {
      throw new Error(`Theme "${newTheme}" is not supported. Supported themes: [${supportedThemes.join(', ')}]`);
    }
  }

  return {
    theme,
    setTheme,
    uikitThemeClass,
  }
}
